Evaluation Metrics
==================

.. currentmodule:: hpipy.utils.metrics

.. autosummary::
   :toctree: _autosummary
   :template: class.rst

   accuracy
   series_accuracy
   insample_error
   kfold_error
   forecast_error
   revision
   volatility
   series_volatility
